@@ -71,7 +71,7 @@ else:
     from pysal import Moran as pysal_Moran
     from pysal import Moran_Local as pysal_Moran_Local
     from pysal import Geary as pysal_Geary
-    from pysal import lat2W as pydal_lat2W
+    from pysal import lat2W as pysal_lat2W
     from pysal import W as pysal_W
 
 # Function to read the original file's projection:
@@ -90,7 +90,7 @@ def get_geo_info(filename, band=1):
     return ndv, xsize, ysize, geot, projection, datatype
 
 # Function to map location in pixel of raster array
-def map_pixel(point_x, point_y, cellx, celly, xmin, ymax, floor=True):
+def map_pixel(point_x, point_y, cellx, celly, xmin, ymax, floor=False):
     '''
     Usage:
         map_pixel(xcoord, ycoord, x_cell_size, y_cell_size, xmin, ymax)
@@ -1256,11 +1256,11 @@ def union(rasters):
         lonmax = max([i.xmax for i in rasters])
         latmin = min([i.ymin for i in rasters])
         latmax = max([i.ymax for i in rasters])
-        shape = (np.abs(np.floor((latmax-latmin)/rasters[0].y_cell_size)).astype(int), np.floor((lonmax-lonmin)/rasters[0].x_cell_size).astype(int))
+        shape = (np.abs(np.round((latmax-latmin)/rasters[0].y_cell_size)).astype(int), np.round((lonmax-lonmin)/rasters[0].x_cell_size).astype(int))
         out = ndv * np.ones(shape)
         outmask = np.ones(shape).astype(bool)
         for i in rasters:
-            (row, col) = map_pixel(i.xmin, i.ymax, rasters[0].x_cell_size, rasters[0].y_cell_size, lonmin, latmax)
+            (row, col) = map_pixel(i.xmin, i.ymax, rasters[0].x_cell_size, rasters[0].y_cell_size, lonmin, latmax, floor=True)
             out[row:row+i.shape[0], col:col+i.shape[1]] = np.where(i.raster.data != i.nodata_value, i.raster.data,\
                                                          out[row:row+i.shape[0], col:col+i.shape[1]])
             outmask[row:row+i.shape[0], col:col+i.shape[1]] = np.where(i.raster.mask == False, False,\
@@ -1312,7 +1312,7 @@ def from_pandas(df, value='value', x='x', y='y', cellx=None, celly=None, xmin=No
         xmin = df[x].min()
     if not ymax:
         ymax = df[y].max()
-    row, col = map_pixel(df[x], df[y], cellx, celly, xmin, ymax, floor=False)
+    row, col = map_pixel(df[x], df[y], cellx, celly, xmin, ymax)
     dfout = pd.DataFrame(np.array([row, col, df[value]]).T, columns=['row', 'col', 'value'])
     dfout = dfout = dfout.set_index(["row","col"]).unstack().value.reindex(index=np.arange(0,np.max(row)+1)).T.reindex(index=np.arange(0,np.max(col)+1)).T
     if nodata_value:
